/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PackerRunTaskConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#id PackerRunTask#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    *
    * The ID of the HCP project where the HCP Packer Registry is located.
    * If not specified, the project specified in the HCP Provider config block will be used, if configured.
    * If a project is not configured in the HCP Provider config block, the oldest project in the organization will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#project_id PackerRunTask#project_id}
    */
    readonly projectId?: string;
    /**
    * If true, the HMAC Key (`hmac_key`) will be regenerated during `terraform apply`. While set to true, the key will be regenerated on every `terraform apply` until `regenerate_hmac` is set to false or removed from the config.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#regenerate_hmac PackerRunTask#regenerate_hmac}
    */
    readonly regenerateHmac?: boolean | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#timeouts PackerRunTask#timeouts}
    */
    readonly timeouts?: PackerRunTaskTimeouts;
}
export interface PackerRunTaskTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#create PackerRunTask#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#default PackerRunTask#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#delete PackerRunTask#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#update PackerRunTask#update}
    */
    readonly update?: string;
}
export declare function packerRunTaskTimeoutsToTerraform(struct?: PackerRunTaskTimeouts | cdktf.IResolvable): any;
export declare function packerRunTaskTimeoutsToHclTerraform(struct?: PackerRunTaskTimeouts | cdktf.IResolvable): any;
export declare class PackerRunTaskTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PackerRunTaskTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: PackerRunTaskTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task hcp_packer_run_task}
*/
export declare class PackerRunTask extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_packer_run_task";
    /**
    * Generates CDKTF code for importing a PackerRunTask resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PackerRunTask to import
    * @param importFromId The id of the existing PackerRunTask that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PackerRunTask to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.83.0/docs/resources/packer_run_task hcp_packer_run_task} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PackerRunTaskConfig = {}
    */
    constructor(scope: Construct, id: string, config?: PackerRunTaskConfig);
    get endpointUrl(): string;
    get hmacKey(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _regenerateHmac?;
    get regenerateHmac(): boolean | cdktf.IResolvable;
    set regenerateHmac(value: boolean | cdktf.IResolvable);
    resetRegenerateHmac(): void;
    get regenerateHmacInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    get timeouts(): PackerRunTaskTimeoutsOutputReference;
    putTimeouts(value: PackerRunTaskTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | PackerRunTaskTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
